@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #       srecord - manipulate eprom load files
-#       Copyright (C) 1998, 2001, 2003, 2005-2007 Peter Miller
+#       Copyright (C) 1998, 2001, 2003, 2005-2008 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ echo "Source: http://srecord.sourceforge.net/%{name}-%{version}.tar.gz"
 echo 'URL: http://srecord.sourceforge.net/'
 echo 'BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)'
 echo
-echo 'BuildRequires:  diffutils, sharutils, groff'
+echo 'BuildRequires:  diffutils, sharutils, groff, gcc-c++, boost-devel'
 
 prefix=/usr
 #
@@ -81,7 +81,7 @@ make
 
 %install
 rm -rf $RPM_BUILD_ROOT
-make install DESTDIR=$RPM_BUILD_ROOT
+make install
 
 
 %check || :
@@ -115,8 +115,11 @@ for file in $*
 do
         case $file in
 
-        prog/*/main.cc)
-                dir=`echo $file | sed 's|prog/\([^/]*\)/.*|\1|'`
+        test_*)
+            ;;
+
+        */main.cc)
+                dir=`echo $file | sed 's|\([^/]*\)/.*|\1|'`
                 remember_prog $dir
                 ;;
 
