@@ -58,6 +58,9 @@ srec_arglex::srec_arglex(int argc, char **argv) :
         { "-Big_Endian_Checksum_Positive", token_checksum_be_positive, },
         { "-Big_Endian_Cyclic_Redundancy_Check_16", token_crc16_be, },
         { "-Big_Endian_Cyclic_Redundancy_Check_32", token_crc32_be, },
+        { "-Big_Endian_Exclusive_Length", token_exclusive_length_be, },
+        { "-Big_Endian_Exclusive_MAximum", token_exclusive_maximum_be, },
+        { "-Big_Endian_Exclusive_MInimum",token_exclusive_minimum_be, },
         { "-Big_Endian_Length", token_length_be, },
         { "-Big_Endian_MAximum", token_maximum_be, },
         { "-Big_Endian_MInimum",token_minimum_be, },
@@ -83,6 +86,9 @@ srec_arglex::srec_arglex(int argc, char **argv) :
         { "-Elektor_Monitor52", token_emon52, },
         { "-Enable_Sequence_Warnings", token_sequence_warnings_enable, },
         { "-Exclude", token_exclude, },
+        { "-Exclusive_Length", token_exclusive_length, },
+        { "-Exclusive_Maximum", token_exclusive_maximum, },
+        { "-Exclusive_Minimum", token_exclusive_minimum, },
         { "-FAIrchild", token_fairchild, },
         { "-Fast_Load", token_fast_load, },
         { "-Fill", token_fill, },
@@ -105,6 +111,9 @@ srec_arglex::srec_arglex(int argc, char **argv) :
         { "-Little_Endian_Checksum_Positive", token_checksum_le_positive, },
         { "-Little_Endian_Cyclic_Redundancy_Check_16", token_crc16_le,},
         { "-Little_Endian_Cyclic_Redundancy_Check_32", token_crc32_le,},
+        { "-Little_Endian_Exclusive_Length", token_exclusive_length_le, },
+        { "-Little_Endian_Exclusive_MAximum", token_exclusive_maximum_le, },
+        { "-Little_Endian_Exclusive_MInimum", token_exclusive_minimum_le, },
         { "-Little_Endian_Length", token_length_le, },
         { "-Little_Endian_MAximum", token_maximum_le, },
         { "-Little_Endian_MInimum", token_minimum_le, },
