@@ -20,6 +20,7 @@
 #include <iostream>
 using namespace std;
 
+#include <lib/quit.h>
 #include <lib/srec/arglex.h>
 #include <lib/srec/input/file/aomf.h>
 #include <lib/srec/input/file/ascii_hex.h>
@@ -33,7 +34,6 @@ using namespace std;
 #include <lib/srec/input/file/fastload.h>
 #include <lib/srec/input/file/formatted_binary.h>
 #include <lib/srec/input/file/four_packed_code.h>
-#include <lib/srec/input/file/guess.h>
 #include <lib/srec/input/file/intel.h>
 #include <lib/srec/input/file/intel16.h>
 #include <lib/srec/input/file/mos_tech.h>
@@ -60,9 +60,9 @@ using namespace std;
 #include <lib/srec/input/filter/crc32.h>
 #include <lib/srec/input/filter/crop.h>
 #include <lib/srec/input/filter/fill.h>
-#include <lib/srec/input/filter/length.h>
-#include <lib/srec/input/filter/maximum.h>
-#include <lib/srec/input/filter/minimum.h>
+#include <lib/srec/input/filter/interval/length.h>
+#include <lib/srec/input/filter/interval/maximum.h>
+#include <lib/srec/input/filter/interval/minimum.h>
 #include <lib/srec/input/filter/not.h>
 #include <lib/srec/input/filter/offset.h>
 #include <lib/srec/input/filter/or.h>
@@ -76,7 +76,97 @@ using namespace std;
 #include <lib/srec/input/interval.h>
 
 
-srec_input *
+endian_t
+srec_arglex::get_endian_by_token(int tok)
+    const
+{
+    switch (tok)
+    {
+    case token_atmel_generic_be:
+    case token_checksum_be_bitnot:
+    case token_checksum_be_negative:
+    case token_checksum_be_positive:
+    case token_crc16_be:
+    case token_crc32_be:
+    case token_exclusive_length_be:
+    case token_exclusive_maximum_be:
+    case token_exclusive_minimum_be:
+    case token_length_be:
+    case token_maximum_be:
+    case token_minimum_be:
+    case token_spasm_be:
+        return endian_big;
+
+    case token_atmel_generic_le:
+    case token_checksum_le_bitnot:
+    case token_checksum_le_negative:
+    case token_checksum_le_positive:
+    case token_crc16_le:
+    case token_crc32_le:
+    case token_exclusive_length_le:
+    case token_exclusive_maximum_le:
+    case token_exclusive_minimum_le:
+    case token_length_le:
+    case token_maximum_le:
+    case token_minimum_le:
+    case token_spasm_le:
+        return endian_little;
+
+    default:
+        quit_default.fatal_error
+        (
+            "%s: %d: add %s to switch (bug)",
+            __FILE__,
+            __LINE__,
+            token_name(tok)
+        );
+        return endian_big;
+    }
+}
+
+
+bool
+srec_arglex::get_inclusive_by_token(int tok)
+    const
+{
+    switch (tok)
+    {
+    case token_exclusive_length:
+    case token_exclusive_length_be:
+    case token_exclusive_length_le:
+    case token_exclusive_maximum:
+    case token_exclusive_maximum_be:
+    case token_exclusive_maximum_le:
+    case token_exclusive_minimum:
+    case token_exclusive_minimum_be:
+    case token_exclusive_minimum_le:
+        return false;
+
+    case token_length:
+    case token_length_be:
+    case token_length_le:
+    case token_maximum:
+    case token_maximum_be:
+    case token_maximum_le:
+    case token_minimum:
+    case token_minimum_be:
+    case token_minimum_le:
+        return true;
+
+    default:
+        quit_default.fatal_error
+        (
+            "%s: %d: add %s to switch (bug)",
+            __FILE__,
+            __LINE__,
+            token_name(tok)
+        );
+        return true;
+    }
+}
+
+
+srec_input::pointer
 srec_arglex::get_simple_input()
 {
     std::string fn = "-";
@@ -85,7 +175,7 @@ srec_arglex::get_simple_input()
     case token_paren_begin:
         {
             token_next();
-            srec_input *ifp = get_input();
+            srec_input::pointer ifp = get_input();
             if (token_cur() != token_paren_end)
             {
                 fatal_error
@@ -130,7 +220,7 @@ srec_arglex::get_simple_input()
     // determine the file format
     // and open the input file
     //
-    srec_input *ifp = 0;
+    srec_input::pointer ifp;
     switch (token_cur())
     {
     case token_motorola:
@@ -138,72 +228,71 @@ srec_arglex::get_simple_input()
         // fall through...
 
     default:
-        ifp = new srec_input_file_srecord(fn);
+        ifp = srec_input_file_srecord::create(fn);
         break;
 
     case token_aomf:
         token_next();
-        ifp = new srec_input_file_aomf(fn);
+        ifp = srec_input_file_aomf::create(fn);
         break;
 
     case token_ascii_hex:
         token_next();
-        ifp = new srec_input_file_ascii_hex(fn);
+        ifp = srec_input_file_ascii_hex::create(fn);
         break;
 
     case token_atmel_generic_be:
-        token_next();
-        ifp = new srec_input_file_atmel_generic(fn, true);
-        break;
-
     case token_atmel_generic_le:
-        token_next();
-        ifp = new srec_input_file_atmel_generic(fn, false);
+        {
+            endian_t end = get_endian_by_token();
+            token_next();
+            ifp = srec_input_file_atmel_generic::create(fn, end);
+        }
         break;
 
     case token_binary:
         token_next();
-        ifp = new srec_input_file_binary(fn);
+        ifp = srec_input_file_binary::create(fn);
         break;
 
     case token_brecord:
         token_next();
-        ifp = new srec_input_file_brecord(fn);
+        ifp = srec_input_file_brecord::create(fn);
         break;
 
     case token_cosmac:
         token_next();
-        ifp = new srec_input_file_cosmac(fn);
+        ifp = srec_input_file_cosmac::create(fn);
         break;
 
     case token_dec_binary:
         token_next();
-        ifp = new srec_input_file_dec_binary(fn);
+        ifp = srec_input_file_dec_binary::create(fn);
         break;
 
     case token_emon52:
         token_next();
-        ifp = new srec_input_file_emon52(fn);
+        ifp = srec_input_file_emon52::create(fn);
         break;
 
     case token_fairchild:
         token_next();
-        ifp = new srec_input_file_fairchild(fn);
+        ifp = srec_input_file_fairchild::create(fn);
         break;
 
     case token_fast_load:
         token_next();
-        ifp = new srec_input_file_fastload(fn);
+        ifp = srec_input_file_fastload::create(fn);
         break;
 
     case token_formatted_binary:
         token_next();
-        ifp = new srec_input_file_formatted_binary(fn);
+        ifp = srec_input_file_formatted_binary::create(fn);
         break;
 
     case token_four_packed_code:
         token_next();
-        ifp = new srec_input_file_four_packed_code(fn);
+        ifp = srec_input_file_four_packed_code::create(fn);
         break;
 
     case token_generator:
@@ -213,92 +302,91 @@ srec_arglex::get_simple_input()
 
     case token_guess:
         token_next();
-        ifp = srec_input_file_guess(fn);
+        ifp = srec_input_file::guess(fn);
         break;
 
     case token_intel:
         token_next();
-        ifp = new srec_input_file_intel(fn);
+        ifp = srec_input_file_intel::create(fn);
         break;
 
     case token_intel16:
         token_next();
-        ifp = new srec_input_file_intel16(fn);
+        ifp = srec_input_file_intel16::create(fn);
         break;
 
     case token_mos_tech:
         token_next();
-        ifp = new srec_input_file_mos_tech(fn);
+        ifp = srec_input_file_mos_tech::create(fn);
         break;
 
     case token_ohio_scientific:
         token_next();
-        ifp = new srec_input_file_os65v(fn);
+        ifp = srec_input_file_os65v::create(fn);
         break;
 
     case token_needham_hex:
         token_next();
-        ifp = new srec_input_file_needham(fn);
+        ifp = srec_input_file_needham::create(fn);
         break;
 
     case token_signetics:
         token_next();
-        ifp = new srec_input_file_signetics(fn);
+        ifp = srec_input_file_signetics::create(fn);
         break;
 
     case token_spasm_be:
-        token_next();
-        ifp = new srec_input_file_spasm(fn, true);
-        break;
-
     case token_spasm_le:
-        token_next();
-        ifp = new srec_input_file_spasm(fn, false);
+        {
+            endian_t end = get_endian_by_token();
+            token_next();
+            ifp = srec_input_file_spasm::create(fn, end);
+        }
         break;
 
     case token_spectrum:
         token_next();
-        ifp = new srec_input_file_spectrum(fn);
+        ifp = srec_input_file_spectrum::create(fn);
         break;
 
     case token_stewie:
         token_next();
-        ifp = new srec_input_file_stewie(fn);
+        ifp = srec_input_file_stewie::create(fn);
         break;
 
     case token_tektronix:
         token_next();
-        ifp = new srec_input_file_tektronix(fn);
+        ifp = srec_input_file_tektronix::create(fn);
         break;
 
     case token_tektronix_extended:
         token_next();
-        ifp = new srec_input_file_tektronix_extended(fn);
+        ifp = srec_input_file_tektronix_extended::create(fn);
         break;
 
     case token_ti_tagged:
         token_next();
-        ifp = new srec_input_file_ti_tagged(fn);
+        ifp = srec_input_file_ti_tagged::create(fn);
         break;
 
     case token_ti_tagged_16:
         token_next();
-        ifp = new srec_input_file_ti_tagged_16(fn);
+        ifp = srec_input_file_ti_tagged_16::create(fn);
         break;
 
     case token_ti_txt:
         token_next();
-        ifp = new srec_input_file_ti_txt(fn);
+        ifp = srec_input_file_ti_txt::create(fn);
         break;
 
     case token_vmem:
         token_next();
-        ifp = new srec_input_file_vmem(fn);
+        ifp = srec_input_file_vmem::create(fn);
         break;
 
     case token_wilson:
         token_next();
-        ifp = new srec_input_file_wilson(fn);
+        ifp = srec_input_file_wilson::create(fn);
         break;
     }
     // assert(ifp);
@@ -321,7 +409,7 @@ srec_arglex::get_simple_input()
     // warn about data record sequences, if asked to
     //
     if (issue_sequence_warnings != 0)
-        ifp = new srec_input_filter_sequence(ifp);
+        ifp = srec_input_filter_sequence::create(ifp);
 
     //
     // report success
@@ -330,10 +418,10 @@ srec_arglex::get_simple_input()
 }
 
 
-srec_input *
+srec_input::pointer
 srec_arglex::get_input()
 {
-    srec_input *ifp = get_simple_input();
+    srec_input::pointer ifp = get_simple_input();
 
     //
     // apply any filters specified
@@ -344,58 +432,47 @@ srec_arglex::get_input()
         {
         case token_byte_swap:
             token_next();
-            ifp = new srec_input_filter_byte_swap(ifp);
+            ifp = srec_input_filter_byte_swap::create(ifp);
             break;
 
         case token_not:
             token_next();
-            ifp = new srec_input_filter_not(ifp);
+            ifp = srec_input_filter_not::create(ifp);
             break;
 
         case token_crc16_be:
-            {
-                token_next();
-                unsigned long address;
-                get_address("-Big_Endian_CRC16", address);
-                ifp = new srec_input_filter_crc16(ifp, address, 0);
-            }
-            break;
-
         case token_crc16_le:
             {
+                endian_t end = get_endian_by_token();
+                const char *name = token_name();
                 token_next();
                 unsigned long address;
-                get_address("-Little_Endian_CRC16", address);
-                ifp = new srec_input_filter_crc16(ifp, address, 1);
+                get_address(name, address);
+                ifp = srec_input_filter_crc16::create(ifp, address, end);
             }
             break;
 
         case token_crc32_be:
-            {
-                token_next();
-                unsigned long address;
-                get_address("-Big_Endian_CRC32", address);
-                ifp = new srec_input_filter_crc32(ifp, address, 0);
-            }
-            break;
-
         case token_crc32_le:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
                 token_next();
                 unsigned long address;
-                get_address("-Little_Endian_CRC32", address);
-                ifp = new srec_input_filter_crc32(ifp, address, 1);
+                get_address(name, address);
+                ifp = srec_input_filter_crc32::create(ifp, address, end);
             }
             break;
 
         case token_crop:
             token_next();
-            ifp = new srec_input_filter_crop(ifp, get_interval("-Crop"));
+            ifp = srec_input_filter_crop::create(ifp, get_interval("-Crop"));
             break;
 
         case token_exclude:
             token_next();
-            ifp = new srec_input_filter_crop(ifp, -get_interval("-Exclude"));
+            ifp =
+                srec_input_filter_crop::create(ifp, -get_interval("-Exclude"));
             break;
 
         case token_fill:
@@ -403,7 +480,7 @@ srec_arglex::get_input()
                 token_next();
                 int filler = get_number("--Fill", 0, 255);
                 interval range = get_interval("--Fill");
-                ifp = new srec_input_filter_fill(ifp, filler, range);
+                ifp = srec_input_filter_fill::create(ifp, filler, range);
             }
             break;
 
@@ -411,7 +488,7 @@ srec_arglex::get_input()
             {
                 token_next();
                 interval range = get_interval("-Random_Fill");
-                ifp = new srec_input_filter_random_fill(ifp, range);
+                ifp = srec_input_filter_random_fill::create(ifp, range);
             }
             break;
 
@@ -424,7 +501,7 @@ srec_arglex::get_input()
                     fatal_error("-and value %d out of range (0..255)", filler);
                     // NOTREACHED
                 }
-                ifp = new srec_input_filter_and(ifp, filler);
+                ifp = srec_input_filter_and::create(ifp, filler);
             }
             break;
 
@@ -432,7 +509,7 @@ srec_arglex::get_input()
             {
                 token_next();
                 int filler = get_number("--xor", 0, 255);
-                ifp = new srec_input_filter_xor(ifp, filler);
+                ifp = srec_input_filter_xor::create(ifp, filler);
             }
             break;
 
@@ -440,7 +517,7 @@ srec_arglex::get_input()
             {
                 token_next();
                 int filler = get_number("--or value", 0, 255);
-                ifp = new srec_input_filter_or(ifp, filler);
+                ifp = srec_input_filter_or::create(ifp, filler);
             }
             break;
 
@@ -448,28 +525,35 @@ srec_arglex::get_input()
             fatal_error("Use --big-endian-length or --little-endian-length");
             // NOTREACHED
 
-        case token_length_be:
-            {
-                token_next();
-                unsigned long address;
-                int nbytes;
-                get_address_and_nbytes("-Big_Endian_Length", address, nbytes);
-                ifp = new srec_input_filter_length(ifp, address, nbytes, 0);
-            }
-            break;
+        case token_exclusive_length:
+            fatal_error
+            (
+                "Use --big-endian-exclusive-length or "
+                    "--little-endian-exclusive-length"
+            );
+            // NOTREACHED
 
+        case token_length_be:
         case token_length_le:
+        case token_exclusive_length_be:
+        case token_exclusive_length_le:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
+                bool inclusive = get_inclusive_by_token();
                 token_next();
                 unsigned long address;
                 int nbytes;
-                get_address_and_nbytes
-                (
-                    "-Little_Endian_Length",
-                    address,
-                    nbytes
-                );
-                ifp = new srec_input_filter_length(ifp, address, nbytes, 1);
+                get_address_and_nbytes(name, address, nbytes);
+                ifp =
+                    srec_input_filter_interval_length::create
+                    (
+                        ifp,
+                        address,
+                        nbytes,
+                        end,
+                        inclusive
+                    );
             }
             break;
 
@@ -477,28 +561,35 @@ srec_arglex::get_input()
             fatal_error("Use --big-endian-maximum or --little-endian-maximum");
             // NOTREACHED
 
-        case token_maximum_be:
-            {
-                token_next();
-                unsigned long address;
-                int nbytes;
-                get_address_and_nbytes("-Big_Endian_MAximum", address, nbytes);
-                ifp = new srec_input_filter_maximum(ifp, address, nbytes, 0);
-            }
-            break;
+        case token_exclusive_maximum:
+            fatal_error
+            (
+                "Use --big-endian-exclusive-maximum or "
+                    "--little-endian-exclusive-maximum"
+            );
+            // NOTREACHED
 
+        case token_maximum_be:
         case token_maximum_le:
+        case token_exclusive_maximum_be:
+        case token_exclusive_maximum_le:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
+                bool inclusive = get_inclusive_by_token();
                 token_next();
                 unsigned long address;
                 int nbytes;
-                get_address_and_nbytes
-                (
-                    "-Little_Endian_MAximum",
-                    address,
-                    nbytes
-                );
-                ifp = new srec_input_filter_maximum(ifp, address, nbytes, 1);
+                get_address_and_nbytes(name, address, nbytes);
+                ifp =
+                    srec_input_filter_interval_maximum::create
+                    (
+                        ifp,
+                        address,
+                        nbytes,
+                        end,
+                        inclusive
+                    );
             }
             break;
 
@@ -506,170 +597,96 @@ srec_arglex::get_input()
             fatal_error("Use --big-endian-minimum or --little-endian-minimum");
             // NOTREACHED
 
+        case token_exclusive_minimum:
+            fatal_error
+            (
+                "Use --big-endian-exclusive-minimum or "
+                    "--little-endian-exclusive-minimum"
+            );
+            // NOTREACHED
+
         case token_minimum_be:
-            {
-                token_next();
-                unsigned long address;
-                int nbytes;
-                get_address_and_nbytes("-Big_Endian_MInimum", address, nbytes);
-                ifp = new srec_input_filter_minimum(ifp, address, nbytes, 0);
-            }
-            break;
-
         case token_minimum_le:
+        case token_exclusive_minimum_be:
+        case token_exclusive_minimum_le:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
+                bool inclusive = get_inclusive_by_token();
                 token_next();
                 unsigned long address;
                 int nbytes;
-                get_address_and_nbytes
-                (
-                    "-Little_Endian_MInimum",
-                    address,
-                    nbytes
-                );
-                ifp = new srec_input_filter_minimum(ifp, address, nbytes, 1);
-            }
-            break;
-
-        case token_checksum_be_bitnot:
-            {
-                token_next();
-                unsigned long address;
-                int nbytes, width;
-                get_address_nbytes_width
-                (
-                    "-Big_Endian_Checksum_BitNot",
-                    address,
-                    nbytes,
-                    width
-                );
+                get_address_and_nbytes(name, address, nbytes);
                 ifp =
-                    new srec_input_filter_checksum_bitnot
+                    srec_input_filter_interval_minimum::create
                     (
                         ifp,
                         address,
                         nbytes,
-                        0,
-                        width
+                        end,
+                        inclusive
                     );
             }
             break;
 
+        case token_checksum_be_bitnot:
         case token_checksum_le_bitnot:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
                 token_next();
                 unsigned long address;
                 int nbytes, width;
-                get_address_nbytes_width
-                (
-                    "-Little_Endian_Checksum_BitNot",
-                    address,
-                    nbytes,
-                    width
-                );
+                get_address_nbytes_width(name, address, nbytes, width);
                 ifp =
-                    new srec_input_filter_checksum_bitnot
+                    srec_input_filter_checksum_bitnot::create
                     (
                         ifp,
                         address,
                         nbytes,
-                        1,
+                        end,
                         width
                     );
             }
             break;
 
         case token_checksum_be_negative:
-            {
-                token_next();
-                unsigned long address;
-                int nbytes, width;
-                get_address_nbytes_width
-                (
-                    "-Big_Endian_Checksum_Negative",
-                    address,
-                    nbytes,
-                    width
-                );
-                ifp =
-                    new srec_input_filter_checksum_negative
-                    (
-                        ifp,
-                        address,
-                        nbytes,
-                        0,
-                        width
-                    );
-            }
-            break;
-
         case token_checksum_le_negative:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
                 token_next();
                 unsigned long address;
                 int nbytes, width;
-                get_address_nbytes_width
-                (
-                    "-Little_Endian_Checksum_Negative",
-                    address,
-                    nbytes,
-                    width
-                );
+                get_address_nbytes_width(name, address, nbytes, width);
                 ifp =
-                    new srec_input_filter_checksum_negative
+                    srec_input_filter_checksum_negative::create
                     (
                         ifp,
                         address,
                         nbytes,
-                        1,
+                        end,
                         width
                     );
             }
             break;
 
         case token_checksum_be_positive:
-            {
-                token_next();
-                unsigned long address;
-                int nbytes, width;
-                get_address_nbytes_width
-                (
-                    "-Big_Endian_Checksum_Positive",
-                    address,
-                    nbytes,
-                    width
-                );
-                ifp =
-                    new srec_input_filter_checksum_positive
-                    (
-                        ifp,
-                        address,
-                        nbytes,
-                        0,
-                        width
-                    );
-            }
-            break;
-
         case token_checksum_le_positive:
             {
+                const char *name = token_name();
+                endian_t end = get_endian_by_token();
                 token_next();
                 unsigned long address;
                 int nbytes, width;
-                get_address_nbytes_width
-                (
-                    "-Little_Endian_Checksum_Positive",
-                    address,
-                    nbytes,
-                    width
-                );
+                get_address_nbytes_width(name, address, nbytes, width);
                 ifp =
-                    new srec_input_filter_checksum_positive
+                    srec_input_filter_checksum_positive::create
                     (
                         ifp,
                         address,
                         nbytes,
-                        1,
+                        end,
                         width
                     );
             }
@@ -679,7 +696,7 @@ srec_arglex::get_input()
             {
                 token_next();
                 unsigned long amount = get_number("--offset");
-                ifp = new srec_input_filter_offset(ifp, amount);
+                ifp = srec_input_filter_offset::create(ifp, amount);
             }
             break;
 
@@ -705,7 +722,7 @@ srec_arglex::get_input()
                         get_number("split width", 1, split_modulus - 1);
                 }
                 ifp =
-                    new srec_input_filter_split
+                    srec_input_filter_split::create
                     (
                         ifp,
                         split_modulus,
@@ -725,7 +742,12 @@ srec_arglex::get_input()
                     fill_minimum = get_number("--unfill minimum", 1, 16);
                 }
                 ifp =
-                    new srec_input_filter_unfill(ifp, fill_value, fill_minimum);
+                    srec_input_filter_unfill::create
+                    (
+                        ifp,
+                        fill_value,
+                        fill_minimum
+                    );
             }
             break;
 
@@ -751,7 +773,7 @@ srec_arglex::get_input()
                         get_number("--unsplit width", 1, split_modulus - 1);
                 }
                 ifp =
-                    new srec_input_filter_unsplit
+                    srec_input_filter_unsplit::create
                     (
                         ifp,
                         split_modulus,
