@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2001-2004, 2006, 2007 Peter Miller
+//      Copyright (C) 2001-2004, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@
 #include <lib/srec/output/file/wilson.h>
 
 
-srec_output *
+srec_output::pointer
 srec_arglex::get_output()
 {
     //
@@ -94,7 +94,7 @@ srec_arglex::get_output()
     //
     // determine the file format
     //
-    srec_output *ofp = 0;
+    srec_output::pointer ofp;
     switch (token_cur())
     {
     case token_motorola:
@@ -102,182 +102,182 @@ srec_arglex::get_output()
         // fall through...
 
     default:
-        ofp = new srec_output_file_srecord(fn.c_str());
+        ofp = srec_output_file_srecord::create(fn);
         break;
 
     case token_aomf:
         token_next();
-        ofp = new srec_output_file_aomf(fn.c_str());
+        ofp = srec_output_file_aomf::create(fn);
         break;
 
     case token_ascii_hex:
         token_next();
-        ofp = new srec_output_file_ascii_hex(fn.c_str());
+        ofp = srec_output_file_ascii_hex::create(fn);
         break;
 
     case token_assembler:
         token_next();
-        ofp = new srec_output_file_asm(fn.c_str());
+        ofp = srec_output_file_asm::create(fn);
         break;
 
     case token_atmel_generic_be:
         token_next();
-        ofp = new srec_output_file_atmel_generic(fn.c_str(), true);
+        ofp = srec_output_file_atmel_generic::create(fn, endian_big);
         break;
 
     case token_atmel_generic_le:
         token_next();
-        ofp = new srec_output_file_atmel_generic(fn.c_str(), false);
+        ofp = srec_output_file_atmel_generic::create(fn, endian_little);
         break;
 
     case token_basic_data:
         token_next();
-        ofp = new srec_output_file_basic(fn.c_str());
+        ofp = srec_output_file_basic::create(fn);
         break;
 
     case token_binary:
         token_next();
-        ofp = new srec_output_file_binary(fn.c_str());
+        ofp = srec_output_file_binary::create(fn);
         break;
 
     case token_brecord:
         token_next();
-        ofp = new srec_output_file_brecord(fn.c_str());
+        ofp = srec_output_file_brecord::create(fn);
         break;
 
     case token_c_array:
         token_next();
-        ofp = new srec_output_file_c(fn.c_str());
+        ofp = srec_output_file_c::create(fn);
         break;
 
     case token_cosmac:
         token_next();
-        ofp = new srec_output_file_cosmac(fn.c_str());
+        ofp = srec_output_file_cosmac::create(fn);
         break;
 
     case token_dec_binary:
         token_next();
-        ofp = new srec_output_file_dec_binary(fn.c_str());
+        ofp = srec_output_file_dec_binary::create(fn);
         break;
 
     case token_emon52:
         token_next();
-        ofp = new srec_output_file_emon52(fn.c_str());
+        ofp = srec_output_file_emon52::create(fn);
         break;
 
     case token_fairchild:
         token_next();
-        ofp = new srec_output_file_fairchild(fn.c_str());
+        ofp = srec_output_file_fairchild::create(fn);
         break;
 
     case token_fast_load:
         token_next();
-        ofp = new srec_output_file_fastload(fn.c_str());
+        ofp = srec_output_file_fastload::create(fn);
         break;
 
     case token_formatted_binary:
         token_next();
-        ofp = new srec_output_file_formatted_binary(fn.c_str());
+        ofp = srec_output_file_formatted_binary::create(fn);
         break;
 
     case token_four_packed_code:
         token_next();
-        ofp = new srec_output_file_four_packed_code(fn.c_str());
+        ofp = srec_output_file_four_packed_code::create(fn);
         break;
 
     case token_hexdump:
         token_next();
-        ofp = new srec_output_file_hexdump(fn.c_str());
+        ofp = srec_output_file_hexdump::create(fn);
         break;
 
     case token_intel:
         token_next();
-        ofp = new srec_output_file_intel(fn.c_str());
+        ofp = srec_output_file_intel::create(fn);
         break;
 
     case token_intel16:
         token_next();
-        ofp = new srec_output_file_intel16(fn.c_str());
+        ofp = srec_output_file_intel16::create(fn);
         break;
 
     case token_mos_tech:
         token_next();
-        ofp = new srec_output_file_mos_tech(fn.c_str());
+        ofp = srec_output_file_mos_tech::create(fn);
         break;
 
     case token_needham_hex:
         token_next();
-        ofp = new srec_output_file_needham(fn.c_str());
+        ofp = srec_output_file_needham::create(fn);
         break;
 
     case token_ohio_scientific:
         token_next();
-        ofp = new srec_output_file_os65v(fn.c_str());
+        ofp = srec_output_file_os65v::create(fn);
         break;
 
     case token_signetics:
         token_next();
-        ofp = new srec_output_file_signetics(fn.c_str());
+        ofp = srec_output_file_signetics::create(fn);
         break;
 
     case token_spasm_be:
         token_next();
-        ofp = new srec_output_file_spasm(fn.c_str(), true);
+        ofp = srec_output_file_spasm::create(fn, endian_big);
         break;
 
     case token_spasm_le:
         token_next();
-        ofp = new srec_output_file_spasm(fn.c_str(), false);
+        ofp = srec_output_file_spasm::create(fn, endian_little);
         break;
 
     case token_spectrum:
         token_next();
-        ofp = new srec_output_file_spectrum(fn.c_str());
+        ofp = srec_output_file_spectrum::create(fn);
         break;
 
     case token_stewie:
         token_next();
-        ofp = new srec_output_file_stewie(fn.c_str());
+        ofp = srec_output_file_stewie::create(fn);
         break;
 
     case token_tektronix:
         token_next();
-        ofp = new srec_output_file_tektronix(fn.c_str());
+        ofp = srec_output_file_tektronix::create(fn);
         break;
 
     case token_tektronix_extended:
         token_next();
-        ofp = new srec_output_file_tektronix_extended(fn.c_str());
+        ofp = srec_output_file_tektronix_extended::create(fn);
         break;
 
     case token_ti_tagged:
         token_next();
-        ofp = new srec_output_file_ti_tagged(fn.c_str());
+        ofp = srec_output_file_ti_tagged::create(fn);
         break;
 
     case token_ti_tagged_16:
         token_next();
-        ofp = new srec_output_file_ti_tagged_16(fn.c_str());
+        ofp = srec_output_file_ti_tagged_16::create(fn);
         break;
 
     case token_ti_txt:
         token_next();
-        ofp = new srec_output_file_ti_txt(fn.c_str());
+        ofp = srec_output_file_ti_txt::create(fn);
         break;
 
     case token_vhdl:
         token_next();
-        ofp = new srec_output_file_vhdl(fn.c_str());
+        ofp = srec_output_file_vhdl::create(fn);
         break;
 
     case token_vmem:
         token_next();
-        ofp = new srec_output_file_vmem(fn.c_str());
+        ofp = srec_output_file_vmem::create(fn);
         break;
 
     case token_wilson:
         token_next();
-        ofp = new srec_output_file_wilson(fn.c_str());
+        ofp = srec_output_file_wilson::create(fn);
         break;
     }
 
