@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998-2000, 2002, 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 1998-2000, 2002, 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,15 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/file/binary.h>
 #include <lib/srec/record.h>
 
 
+srec_input_file_binary::~srec_input_file_binary()
+{
+}
+
+
 srec_input_file_binary::srec_input_file_binary(const string &a_file_name) :
     srec_input_file(a_file_name),
     address(0)
@@ -29,12 +33,14 @@ srec_input_file_binary::srec_input_file_binary(const string &a_file_name) :
 }
 
 
-srec_input_file_binary::~srec_input_file_binary()
+srec_input::pointer
+srec_input_file_binary::create(const string &a_file_name)
 {
+    return pointer(new srec_input_file_binary(a_file_name));
 }
 
 
-int
+bool
 srec_input_file_binary::read(srec_record &record)
 {
 #ifdef HAVE_SPARSE_LSEEK
@@ -53,7 +59,7 @@ srec_input_file_binary::read(srec_record &record)
 
     int c = get_char();
     if (c < 0)
-        return 0;
+        return false;
     int length = 0;
     unsigned char data[srec_record::max_data_length];
     for (;;)
@@ -67,7 +73,7 @@ srec_input_file_binary::read(srec_record &record)
     }
     record = srec_record(srec_record::type_data, address, data, length);
     address += length;
-    return 1;
+    return true;
 }
 
 
