@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/file/cosmac.h>
 #include <lib/srec/record.h>
 
@@ -36,7 +35,14 @@ srec_input_file_cosmac::srec_input_file_cosmac(const string &a_file_name) :
 }
 
 
-int
+srec_input::pointer
+srec_input_file_cosmac::create(const string &a_file_name)
+{
+    return pointer(new srec_input_file_cosmac(a_file_name));
+}
+
+
+bool
 srec_input_file_cosmac::read(srec_record &record)
 {
     for (;;)
@@ -50,7 +56,7 @@ srec_input_file_cosmac::read(srec_record &record)
             {
                 if (!seen_some_input)
                     fatal_error("file contains no data");
-                return 0;
+                return false;
             }
             if (c != '!')
             {
@@ -128,7 +134,7 @@ srec_input_file_cosmac::read(srec_record &record)
             record = srec_record(srec_record::type_data, address, &data, 1);
             ++address;
             seen_some_input = true;
-            return 1;
+            return true;
         }
     }
 }
