@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2001-2003, 2005-2007 Peter Miller
+//      Copyright (C) 2001-2003, 2005-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -22,14 +22,21 @@
 #include <lib/srec/record.h>
 
 
+srec_input_file_emon52::~srec_input_file_emon52()
+{
+}
+
+
 srec_input_file_emon52::srec_input_file_emon52(const string &a_file_name) :
     srec_input_file(a_file_name)
 {
 }
 
 
-srec_input_file_emon52::~srec_input_file_emon52()
+srec_input::pointer
+srec_input_file_emon52::create(const string &a_file_name)
 {
+    return pointer(new srec_input_file_emon52(a_file_name));
 }
 
 
@@ -46,7 +53,7 @@ srec_input_file_emon52::skip_white_space()
 }
 
 
-int
+bool
 srec_input_file_emon52::read(srec_record &record)
 {
     //
@@ -54,7 +61,7 @@ srec_input_file_emon52::read(srec_record &record)
     // character.  So look ahead to see if there is anything more.
     //
     if (peek_char() < 0)
-        return 0;
+        return false;
 
     //
     // Looks like there should be a record.  Read it all in.
@@ -83,7 +90,7 @@ srec_input_file_emon52::read(srec_record &record)
 
     srec_record::type_t type = srec_record::type_data;
     record = srec_record(type, address, buffer, length);
-    return 1;
+    return true;
 }
 
 
