@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/file/formatted_binary.h>
 #include <lib/srec/record.h>
 
@@ -39,7 +38,14 @@ srec_input_file_formatted_binary::srec_input_file_formatted_binary(
 }
 
 
-int
+srec_input::pointer
+srec_input_file_formatted_binary::create(const string &a_file_name)
+{
+    return pointer(new srec_input_file_formatted_binary(a_file_name));
+}
+
+
+bool
 srec_input_file_formatted_binary::read(srec_record &record)
 {
     if (!header_seen)
@@ -134,7 +140,7 @@ srec_input_file_formatted_binary::read(srec_record &record)
             }
             trailer_seen = true;
         }
-        return 0;
+        return false;
     }
 
     long datalen = upper_bound - address;
@@ -151,7 +157,7 @@ srec_input_file_formatted_binary::read(srec_record &record)
     }
     record = srec_record(srec_record::type_data, address, data, datalen);
     address += datalen;
-    return 1;
+    return true;
 }
 
 
