@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <cctype>
 
 #include <lib/srec/input/file/needham.h>
@@ -37,7 +36,14 @@ srec_input_file_needham::srec_input_file_needham(const string &a_file_name) :
 }
 
 
-int
+srec_input::pointer
+srec_input_file_needham::create(const string &a_file_name)
+{
+    return pointer(new srec_input_file_needham(a_file_name));
+}
+
+
+bool
 srec_input_file_needham::read(srec_record &record)
 {
     for (;;)
@@ -47,7 +53,7 @@ srec_input_file_needham::read(srec_record &record)
         {
             if (!seen_some_input)
                 fatal_error("file contains no data");
-            return 0;
+            return false;
         }
         if (isxdigit(c))
         {
@@ -62,7 +68,7 @@ srec_input_file_needham::read(srec_record &record)
                 );
             seen_some_input = true;
             ++address;
-            return 1;
+            return true;
         }
         c = get_char();
         switch (c)
