@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/file/os65v.h>
 #include <lib/srec/record.h>
 
@@ -37,6 +36,13 @@ srec_input_file_os65v::srec_input_file_os65v(const string &a_file_name) :
 }
 
 
+srec_input::pointer
+srec_input_file_os65v::create(const string &a_file_name)
+{
+    return pointer(new srec_input_file_os65v(a_file_name));
+}
+
+
 int
 srec_input_file_os65v::read_inner(srec_record &record)
 {
@@ -140,17 +146,17 @@ srec_input_file_os65v::read_inner(srec_record &record)
 }
 
 
-int
+bool
 srec_input_file_os65v::read(srec_record &record)
 {
     if (!read_inner(record))
     {
         if (!seen_some_input)
             fatal_error("file contains no data");
-        return 0;
+        return false;
     }
     seen_some_input = true;
-    return 1;
+    return true;
 }
 
 
