@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2001-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2001-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,26 +17,39 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/file/spasm.h>
 #include <ctype.h>
 #include <lib/srec/record.h>
 
 
-srec_input_file_spasm::srec_input_file_spasm(const string &a_file_name,
-        bool arg2) :
-    srec_input_file(a_file_name),
-    seen_some_input(false),
-    bigend(arg2)
+srec_input_file_spasm::~srec_input_file_spasm()
 {
 }
 
 
-srec_input_file_spasm::~srec_input_file_spasm()
+srec_input_file_spasm::srec_input_file_spasm(const string &a_file_name,
+        endian_t a_end) :
+    srec_input_file(a_file_name),
+    seen_some_input(false),
+    end(a_end)
 {
 }
 
 
+srec_input::pointer
+srec_input_file_spasm::create_be(const string &a_file_name)
+{
+    return create(a_file_name, endian_big);
+}
+
+
+srec_input::pointer
+srec_input_file_spasm::create(const string &a_file_name, endian_t a_end)
+{
+    return pointer(new srec_input_file_spasm(a_file_name, a_end));
+}
+
+
 int
 srec_input_file_spasm::read_inner(srec_record &record)
 {
@@ -47,8 +60,16 @@ srec_input_file_spasm::read_inner(srec_record &record)
     if (get_char() != ' ')
         fatal_error("space expected");
     unsigned char data[2];
-    data[bigend] = get_byte();
-    data[!bigend] = get_byte();
+    if (end == endian_big)
+    {
+        data[1] = get_byte();
+        data[0] = get_byte();
+    }
+    else
+    {
+        data[0] = get_byte();
+        data[1] = get_byte();
+    }
     if (get_char() != '\n')
         fatal_error("end of line expected");
 
@@ -64,17 +85,17 @@ srec_input_file_spasm::read_inner(srec_record &record)
 }
 
 
-int
+bool
 srec_input_file_spasm::read(srec_record &record)
 {
     if (!read_inner(record))
     {
         if (!seen_some_input)
             fatal_error("file contains no data");
-        return 0;
+        return false;
     }
     seen_some_input = true;
-    return 1;
+    return true;
 }
 
 
@@ -82,5 +103,12 @@ const char *
 srec_input_file_spasm::get_file_format_name()
     const
 {
-    return (bigend ? "SPASM (big-endian)" : "SPASM (little-endian)");
+    return
+        (
+            end == endian_big
+        ?
+            "SPASM (big-endian)"
+        :
+            "SPASM (little-endian)"
+        );
 }
