@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <cctype>
 
 #include <lib/srec/input/file/spectrum.h>
@@ -38,6 +37,13 @@ srec_input_file_spectrum::srec_input_file_spectrum(const string &a_file_name) :
 }
 
 
+srec_input::pointer
+srec_input_file_spectrum::create(const string &a_file_name)
+{
+    return pointer(new srec_input_file_spectrum(a_file_name));
+}
+
+
 int
 srec_input_file_spectrum::get_decimal()
 {
@@ -113,7 +119,7 @@ srec_input_file_spectrum::get_binary()
 }
 
 
-int
+bool
 srec_input_file_spectrum::read(srec_record &record)
 {
     //
@@ -144,7 +150,7 @@ srec_input_file_spectrum::read(srec_record &record)
     // Check for the file trailer.
     //
     if (trailer_seen)
-        return 0;
+        return false;
     for (;;)
     {
         int c = get_char();
@@ -153,7 +159,7 @@ srec_input_file_spectrum::read(srec_record &record)
             if (!file_contains_data)
                 fatal_error("file contains no data");
             trailer_seen = true;
-            return 0;
+            return false;
         }
         if (isspace((unsigned char)c))
             continue;
@@ -165,7 +171,7 @@ srec_input_file_spectrum::read(srec_record &record)
     unsigned char data = get_binary();
     record = srec_record(srec_record::type_data, address, &data, 1);
     file_contains_data = true;
-    return 1;
+    return true;
 }
 
 const char *
