@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2000-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,15 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/file/tektronix_extended.h>
 #include <lib/srec/record.h>
 
 
+srec_input_file_tektronix_extended::~srec_input_file_tektronix_extended()
+{
+}
+
+
 srec_input_file_tektronix_extended::srec_input_file_tektronix_extended(
         const string &a_file_name) :
     srec_input_file(a_file_name),
@@ -32,8 +36,10 @@ srec_input_file_tektronix_extended::srec_input_file_tektronix_extended(
 }
 
 
-srec_input_file_tektronix_extended::~srec_input_file_tektronix_extended()
+srec_input::pointer
+srec_input_file_tektronix_extended::create(const string &a_file_name)
 {
+    return pointer(new srec_input_file_tektronix_extended(a_file_name));
 }
 
 
@@ -121,7 +127,7 @@ srec_input_file_tektronix_extended::read_inner(srec_record &record)
 }
 
 
-int
+bool
 srec_input_file_tektronix_extended::read(srec_record &record)
 {
     for (;;)
@@ -135,7 +141,7 @@ srec_input_file_tektronix_extended::read(srec_record &record)
                 warning("no start address record");
                 termination_seen = true;
             }
-            return 0;
+            return false;
         }
         seen_some_input = true;
         if
@@ -178,7 +184,7 @@ srec_input_file_tektronix_extended::read(srec_record &record)
         }
         break;
     }
-    return 1;
+    return true;
 }
 
 
