@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000, 2002, 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2000, 2002, 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,12 +17,16 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <cctype>
 #include <lib/srec/input/file/ti_tagged.h>
 #include <lib/srec/record.h>
 
 
+srec_input_file_ti_tagged::~srec_input_file_ti_tagged()
+{
+}
+
+
 srec_input_file_ti_tagged::srec_input_file_ti_tagged(const string &a_filename) :
     srec_input_file(a_filename),
     address(0),
@@ -31,8 +35,10 @@ srec_input_file_ti_tagged::srec_input_file_ti_tagged(const string &a_filename) :
 }
 
 
-srec_input_file_ti_tagged::~srec_input_file_ti_tagged()
+srec_input::pointer
+srec_input_file_ti_tagged::create(const string &a_file_name)
 {
+    return pointer(new srec_input_file_ti_tagged(a_file_name));
 }
 
 
@@ -48,7 +54,7 @@ srec_input_file_ti_tagged::get_char()
 }
 
 
-int
+bool
 srec_input_file_ti_tagged::read(srec_record &record)
 {
     for (;;)
@@ -64,7 +70,7 @@ srec_input_file_ti_tagged::read(srec_record &record)
             );
 
         case -1:
-            return 0;
+            return false;
 
         case '*':
             {
@@ -73,14 +79,14 @@ srec_input_file_ti_tagged::read(srec_record &record)
                 data[0] = get_byte();
                 record = srec_record(srec_record::type_data, address, data, 1);
                 ++address;
-                return 1;
+                return true;
             }
 
         case ':':
             // end of file
             while (get_char() >= 0)
                 ;
-            return 0;
+            return false;
 
         case '0':
             {
@@ -128,7 +134,7 @@ srec_input_file_ti_tagged::read(srec_record &record)
                 data[1] = get_byte();
                 record = srec_record(srec_record::type_data, address, data, 2);
                 address += 2;
-                return 1;
+                return true;
             }
 
         case 'F':
@@ -162,7 +168,7 @@ srec_input_file_ti_tagged::read(srec_record &record)
                 record = srec_record(srec_record::type_header, 0, buffer, n);
                 delete buffer;
             }
-            return 1;
+            return true;
         }
     }
 }
