@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2000-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
+#include <lib/srec/arglex.h>
 #include <lib/srec/input/filter/crc32.h>
 #include <lib/srec/memory.h>
 #include <lib/srec/memory/walker/crc32.h>
@@ -26,38 +26,68 @@
 
 srec_input_filter_crc32::~srec_input_filter_crc32()
 {
-        delete buffer;
-        buffer = 0;
 }
 
 
-srec_input_filter_crc32::srec_input_filter_crc32(srec_input *deeper_arg,
-                unsigned long address_arg, int order_arg) :
-        srec_input_filter(deeper_arg),
-        address(address_arg),
-        order(order_arg),
-        buffer(0),
-        buffer_pos(0),
-        have_forwarded_header(false),
-        have_given_crc(false),
-        have_forwarded_start_address(false)
+srec_input_filter_crc32::srec_input_filter_crc32(
+        const srec_input::pointer &deeper_arg, unsigned long address_arg,
+        endian_t a_end) :
+    srec_input_filter(deeper_arg),
+    address(address_arg),
+    end(a_end),
+    buffer_pos(0),
+    have_forwarded_header(false),
+    have_given_crc(false),
+    have_forwarded_start_address(false),
+    seed_mode(crc32::seed_mode_ccitt)
 {
 }
 
 
-int
+srec_input::pointer
+srec_input_filter_crc32::create(const srec_input::pointer &a_deeper,
+    unsigned long a_address, endian_t a_end)
+{
+    return pointer(new srec_input_filter_crc32(a_deeper, a_address, a_end));
+}
+
+
+void
+srec_input_filter_crc32::command_line(srec_arglex *cmdln)
+{
+    for (;;)
+    {
+        switch (cmdln->token_cur())
+        {
+        case srec_arglex::token_crc16_xmodem:
+            seed_mode = crc32::seed_mode_xmodem;
+            cmdln->token_next();
+            break;
+
+        case srec_arglex::token_crc16_ccitt:
+            seed_mode = crc32::seed_mode_ccitt;
+            cmdln->token_next();
+            break;
+
+        default:
+            return;
+        }
+    }
+}
+
+
+bool
 srec_input_filter_crc32::read(srec_record &record)
 {
     //
     // If we haven't read the deeper input yet, read all of it into
     // a memory buffer, then crc32 the bytes.
     //
-    if (!buffer)
+    if (buffer.empty())
     {
-        buffer = new srec_memory();
-        buffer->reader(ifp, true);
+        buffer.reader(ifp, true);
 
-        if (buffer->has_holes())
+        if (buffer.has_holes())
         {
             warning
             (
@@ -79,11 +109,11 @@ srec_input_filter_crc32::read(srec_record &record)
     if (!have_forwarded_header)
     {
         have_forwarded_header = true;
-        srec_record *rp = buffer->get_header();
+        srec_record *rp = buffer.get_header();
         if (rp)
         {
             record = *rp;
-            return 1;
+            return true;
         }
     }
 
@@ -95,21 +125,19 @@ srec_input_filter_crc32::read(srec_record &record)
         // Now CRC32 the bytes in order from lowest address to
         // highest.  (Holes are ignored, not filled.)
         //
-        srec_memory_walker_crc32 walker;
-        buffer->walk(&walker);
-        unsigned long crc = walker.get();
+        srec_memory_walker_crc32::pointer w =
+            srec_memory_walker_crc32::create(seed_mode);
+        buffer.walk(w);
+        unsigned long crc = w->get();
 
         //
         // Turn the CRC into the first data record.
         //
         unsigned char chunk[4];
-        if (order)
-            srec_record::encode_little_endian(chunk, crc, sizeof(chunk));
-        else
-            srec_record::encode_big_endian(chunk, crc, sizeof(chunk));
+        srec_record::encode(chunk, crc, sizeof(chunk), end);
         record =
             srec_record(srec_record::type_data, address, chunk, sizeof(chunk));
-        return 1;
+        return true;
     }
 
     //
@@ -118,11 +146,11 @@ srec_input_filter_crc32::read(srec_record &record)
     unsigned long ret_address = buffer_pos;
     unsigned char data[64];
     size_t nbytes = sizeof(data);
-    if (buffer->find_next_data(ret_address, data, nbytes))
+    if (buffer.find_next_data(ret_address, data, nbytes))
     {
         record = srec_record(srec_record::type_data, ret_address, data, nbytes);
         buffer_pos = ret_address + nbytes;
-        return 1;
+        return true;
     }
 
     //
@@ -131,16 +159,16 @@ srec_input_filter_crc32::read(srec_record &record)
     if (!have_forwarded_start_address)
     {
         have_forwarded_start_address = true;
-        srec_record *rp = buffer->get_start_address();
+        srec_record *rp = buffer.get_start_address();
         if (rp)
         {
             record = *rp;
-            return 1;
+            return true;
         }
     }
 
     //
     // All done.
     //
-    return 0;
+    return false;
 }
