@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001, 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 1998, 1999, 2001, 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -22,22 +22,30 @@
 #include <lib/srec/record.h>
 
 
-srec_input_filter_crop::srec_input_filter_crop(srec_input *a1,
-        const interval &a2) :
-    srec_input_filter(a1),
-    range(a2),
+srec_input_filter_crop::~srec_input_filter_crop()
+{
+}
+
+
+srec_input_filter_crop::srec_input_filter_crop(
+        const srec_input::pointer &a_deeper, const interval &a_range) :
+    srec_input_filter(a_deeper),
+    range(a_range),
     data(),
     data_range()
 {
 }
 
 
-srec_input_filter_crop::~srec_input_filter_crop()
+srec_input::pointer
+srec_input_filter_crop::create(const srec_input::pointer &a_deeper,
+    const interval &a_range)
 {
+    return pointer(new srec_input_filter_crop(a_deeper, a_range));
 }
 
 
-int
+bool
 srec_input_filter_crop::read(srec_record &record)
 {
     for (;;)
@@ -52,16 +60,18 @@ srec_input_filter_crop::read(srec_record &record)
             // If the input is exhausted, we are done.
             //
             if (!srec_input_filter::read(data))
-                return 0;
+            {
+                return false;
+            }
             switch (data.get_type())
             {
             default:
                 //
-                // If the input is of a typoe we don't
+                // If the input is of a type we don't
                 // care about, pass it through.
                 //
                 record = data;
-                return 1;
+                return true;
 
             case srec_record::type_data:
                 //
@@ -85,7 +95,7 @@ srec_input_filter_crop::read(srec_record &record)
                 if (!range.member(data.get_address()))
                     continue;
                 record = data;
-                return 1;
+                return true;
             }
         }
 
@@ -127,6 +137,6 @@ srec_input_filter_crop::read(srec_record &record)
         //
         // Success
         //
-        return 1;
+        return true;
     }
 }
