@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001, 2002, 2005-2007 Peter Miller
+//      Copyright (C) 1998, 1999, 2001, 2002, 2005-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,28 +17,36 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/filter/offset.h>
 #include <lib/srec/record.h>
 
 
-srec_input_filter_offset::srec_input_filter_offset(srec_input *a1, long a2) :
-    srec_input_filter(a1),
-    nbytes(a2)
-{
-}
-
-
 srec_input_filter_offset::~srec_input_filter_offset()
 {
 }
 
 
-int
+srec_input_filter_offset::srec_input_filter_offset(
+        const srec_input::pointer &a1, long a2) :
+    srec_input_filter(a1),
+    nbytes(a2)
+{
+}
+
+
+srec_input::pointer
+srec_input_filter_offset::create(const srec_input::pointer &a_deeper,
+    long nbytes)
+{
+    return pointer(new srec_input_filter_offset(a_deeper, nbytes));
+}
+
+
+bool
 srec_input_filter_offset::read(srec_record &record)
 {
     if (!srec_input_filter::read(record))
-        return 0;
+        return false;
     long addr = record.get_address() + nbytes;
 
     //
@@ -50,5 +58,5 @@ srec_input_filter_offset::read(srec_record &record)
     addr &= 0xFFFFFFFF;
 
     record.set_address(addr);
-    return 1;
+    return true;
 }
