@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2004, 2006, 2007 Peter Miller
+//      Copyright (C) 2004, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
+#include <cstring>
+
 #include <lib/srec/output/file/aomf.h>
 #include <lib/srec/record.h>
 
@@ -26,15 +28,16 @@ srec_output_file_aomf::~srec_output_file_aomf()
 }
 
 
-srec_output_file_aomf::srec_output_file_aomf() :
-    srec_output_file()
+srec_output_file_aomf::srec_output_file_aomf(const std::string &a_file_name) :
+    srec_output_file(a_file_name)
 {
 }
 
 
-srec_output_file_aomf::srec_output_file_aomf(const std::string &a_file_name) :
-    srec_output_file(a_file_name)
+srec_output::pointer
+srec_output_file_aomf::create(const std::string &a_file_name)
 {
+    return pointer(new srec_output_file_aomf(a_file_name));
 }
 
 
