@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2000-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -21,6 +21,12 @@
 #include <lib/srec/record.h>
 
 
+srec_output_file_ascii_hex::~srec_output_file_ascii_hex()
+{
+    emit_end_of_file();
+}
+
+
 srec_output_file_ascii_hex::srec_output_file_ascii_hex(
         const std::string &a_file_name) :
     srec_output_file(a_file_name),
@@ -35,9 +41,10 @@ srec_output_file_ascii_hex::srec_output_file_ascii_hex(
 }
 
 
-srec_output_file_ascii_hex::~srec_output_file_ascii_hex()
+srec_output::pointer
+srec_output_file_ascii_hex::create(const std::string &a_file_name)
 {
-    emit_end_of_file();
+    return pointer(new srec_output_file_ascii_hex(a_file_name));
 }
 
 
