@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,10 +17,29 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
+#include <cstring>
+
 #include <lib/interval.h>
 #include <lib/srec/output/file/basic.h>
 #include <lib/srec/record.h>
-#include <cstdio> // for sprintf
+
+
+srec_output_file_basic::~srec_output_file_basic()
+{
+    if (range.empty())
+        emit_byte(0xFF);
+    if (column)
+        put_char('\n');
+
+    if (!data_only_flag)
+    {
+        put_stringf("REM termination = %lu\n", taddr);
+        put_stringf("REM start = %lu\n", range.get_lowest());
+        put_stringf("REM finish = %lu\n", range.get_highest());
+    }
+    unsigned long len = range.get_highest() - range.get_lowest();
+    put_stringf("REM length = %lu\n", len);
+}
 
 
 srec_output_file_basic::srec_output_file_basic(const string &a_file_name) :
@@ -33,6 +52,13 @@ srec_output_file_basic::srec_output_file_basic(const string &a_file_name) :
 }
 
 
+srec_output::pointer
+srec_output_file_basic::create(const std::string &a_file_name)
+{
+    return pointer(new srec_output_file_basic(a_file_name));
+}
+
+
 void
 srec_output_file_basic::emit_byte(int n)
 {
@@ -60,24 +86,6 @@ srec_output_file_basic::emit_byte(int n)
 }
 
 
-srec_output_file_basic::~srec_output_file_basic()
-{
-    if (range.empty())
-        emit_byte(0xFF);
-    if (column)
-        put_char('\n');
-
-    if (!data_only_flag)
-    {
-        put_stringf("REM termination = %lu\n", taddr);
-        put_stringf("REM start = %lu\n", range.get_lowest());
-        put_stringf("REM finish = %lu\n", range.get_highest());
-    }
-    unsigned long len = range.get_highest() - range.get_lowest();
-    put_stringf("REM length = %lu\n", len);
-}
-
-
 void
 srec_output_file_basic::write(const srec_record &record)
 {
