@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 1998, 1999, 2001-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -21,6 +21,11 @@
 #include <lib/srec/record.h>
 
 
+srec_output_file_binary::~srec_output_file_binary()
+{
+}
+
+
 srec_output_file_binary::srec_output_file_binary(
         const std::string &a_file_name) :
     srec_output_file(a_file_name)
@@ -28,8 +33,10 @@ srec_output_file_binary::srec_output_file_binary(
 }
 
 
-srec_output_file_binary::~srec_output_file_binary()
+srec_output::pointer
+srec_output_file_binary::create(const std::string &a_file_name)
 {
+    return pointer(new srec_output_file_binary(a_file_name));
 }
 
 
