@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 1998-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -26,207 +26,6 @@
 #include <lib/srec/record.h>
 
 
-static const char *
-memrchr(const char *data, char c, size_t len)
-{
-    if (!data)
-        return 0;
-    const char *result = 0;
-    while (len > 0)
-    {
-        const char *p = (const char *)memchr(data, c, len);
-        if (!p)
-            break;
-        result = p;
-        size_t chunk = p - data + 1;
-        data += chunk;
-        len -= chunk;
-    }
-    return result;
-}
-
-
-static string
-build_include_file_name(const string &filename)
-{
-    const char *fn = filename.c_str();
-    // Watch out for out base class adding a line number.
-    const char *colon = strstr(fn, ": ");
-    if (!colon)
-        colon = fn + strlen(fn);
-    const char *slash = memrchr(fn, '/', colon - fn);
-    if (!slash)
-        slash = memrchr(fn, '\\', colon - fn);
-    if (slash)
-        slash++;
-    else
-        slash = fn;
-    const char *ep = memrchr(slash, '.', colon - slash);
-    if (!ep)
-        ep = colon;
-    return (string(fn, ep - fn) + ".h");
-}
-
-
-srec_output_file_c::srec_output_file_c(const string &a_file_name) :
-    srec_output_file(a_file_name),
-    prefix("eprom"),
-    taddr(0),
-    header_done(false),
-    column(0),
-    current_address(0),
-    line_length(75),
-    address_length(4),
-    constant(true),
-    include(false),
-    include_file_name(build_include_file_name(a_file_name)),
-    output_word(false),
-    hex_style(true),
-    section_style(false)
-{
-}
-
-
-void
-srec_output_file_c::command_line(srec_arglex *cmdln)
-{
-    if (cmdln->token_cur() == arglex::token_string)
-    {
-        prefix = cmdln->value_string();
-        cmdln->token_next();
-    }
-    for (;;)
-    {
-        switch (cmdln->token_cur())
-        {
-        case srec_arglex::token_constant:
-            cmdln->token_next();
-            constant = true;
-            break;
-
-        case srec_arglex::token_constant_not:
-            cmdln->token_next();
-            constant = false;
-            break;
-
-        case srec_arglex::token_include:
-            cmdln->token_next();
-            include = true;
-            break;
-
-        case srec_arglex::token_include_not:
-            cmdln->token_next();
-            include = false;
-            break;
-
-        case srec_arglex::token_c_compressed:
-            cmdln->token_next();
-            hex_style = true;
-            section_style = true;
-            break;
-
-        case srec_arglex::token_output_word:
-            cmdln->token_next();
-            output_word = true;
-            break;
-
-        case srec_arglex::token_style_hexadecimal:
-            cmdln->token_next();
-            hex_style = true;
-            break;
-
-        case srec_arglex::token_style_hexadecimal_not:
-            cmdln->token_next();
-            hex_style = false;
-            break;
-
-        case srec_arglex::token_style_section:
-        case srec_arglex::token_a430:
-        case srec_arglex::token_cl430:
-            cmdln->token_next();
-            section_style = true;
-            break;
-
-        default:
-            return;
-        }
-    }
-}
-
-
-void
-srec_output_file_c::emit_header()
-{
-    if (header_done)
-        return;
-    if (constant)
-        put_stringf("const ");
-    if (output_word)
-        put_string("unsigned short");
-    else
-        put_string("unsigned char");
-    put_char(' ');
-    put_string(prefix.c_str());
-    put_string("[] =\n{\n");
-    header_done = true;
-    column = 0;
-}
-
-
-void
-srec_output_file_c::emit_byte(int n)
-{
-    char buffer[30];
-    if (hex_style)
-        snprintf(buffer, sizeof(buffer), "0x%2.2X", (unsigned char)n);
-    else
-        snprintf(buffer, sizeof(buffer), "%u", (unsigned char)n);
-    int len = strlen(buffer);
-
-    if (column && column + 2 + len > line_length)
-    {
-        put_char('\n');
-        column = 0;
-    }
-    if (column)
-    {
-        put_char(' ');
-        ++column;
-    }
-    put_string(buffer);
-    column += len;
-    put_char(',');
-    ++column;
-}
-
-
-void
-srec_output_file_c::emit_word(unsigned int n)
-{
-    char buffer[30];
-    if (hex_style)
-        snprintf(buffer, sizeof(buffer), "0x%4.4X", (unsigned short)n);
-    else
-        snprintf(buffer, sizeof(buffer), "%u", (unsigned short)n);
-    int len = strlen(buffer);
-
-    if (column && column + 2 + len > line_length)
-    {
-        put_char('\n');
-        column = 0;
-    }
-    if (column)
-    {
-        put_char(' ');
-        ++column;
-    }
-    put_string(buffer);
-    column += len;
-    put_char(',');
-    ++column;
-}
-
-
 static string
 toupper(const string &s)
 {
@@ -269,18 +68,6 @@ identifier(const string &s)
 }
 
 
-string
-srec_output_file_c::format_address(unsigned long addr)
-{
-    char buffer[30];
-    if (hex_style)
-        snprintf(buffer, sizeof(buffer), "0x%0*lX", address_length * 2, addr);
-    else
-        snprintf(buffer, sizeof(buffer), "%lu", addr);
-    return buffer;
-}
-
-
 srec_output_file_c::~srec_output_file_c()
 {
     //
@@ -344,6 +131,50 @@ srec_output_file_c::~srec_output_file_c()
         }
         put_stringf("};\n");
 
+        //
+        // emit list of section word addresses
+        // (assuming memoryaddresses are word-wide).
+        //
+        if (output_word)
+        {
+            if (constant)
+                put_string("const ");
+            put_stringf("unsigned long %s_word_address[] =\n{\n",
+                        prefix.c_str());
+            x = range;
+            while (!x.empty())
+            {
+                interval x2 = x;
+                x2.first_interval_only();
+                x -= x2;
+                unsigned long address = x2.get_lowest() / 2;
+
+                string s = format_address(address);
+                int len = s.size();
+
+                if (column && column + len + 2 > line_length)
+                {
+                    put_char('\n');
+                    column = 0;
+                }
+                if (column)
+                {
+                    put_char(' ');
+                    ++column;
+                }
+                put_string(s);
+                column += len;
+                put_char(',');
+                ++column;
+            }
+            if (column)
+            {
+                put_char('\n');
+                column = 0;
+            }
+            put_stringf("};\n");
+        }
+
         //
         // emit list of section lengths
         //
@@ -516,7 +347,30 @@ srec_output_file_c::~srec_output_file_c()
         }
         if (constant)
             fprintf(fp, "const ");
-        fprintf(fp, "extern unsigned char %s[];\n", prefix.c_str());
+        fprintf(fp, "extern unsigned ");
+        if (output_word)
+            fprintf(fp, "short");
+        else
+            fprintf(fp, "char");
+        fprintf(fp, " %s[];\n", prefix.c_str());
+        if (section_style)
+        {
+            if (constant)
+                fprintf(fp, "const ");
+            fprintf(fp, "extern unsigned long");
+            fprintf(fp, " %s_address[];\n", prefix.c_str());
+            if (output_word)
+            {
+                if (constant)
+                    fprintf(fp, "const ");
+                fprintf(fp, "extern unsigned long");
+                fprintf(fp, " %s_word_address[];\n", prefix.c_str());
+            }
+            if (constant)
+                fprintf(fp, "const ");
+            fprintf(fp, "extern unsigned long");
+            fprintf(fp, " %s_length_of_sections[];\n", prefix.c_str());
+        }
         fprintf(fp, "\n");
         fprintf(fp, "#endif /* %s */\n", insulation.c_str());
 
@@ -526,6 +380,226 @@ srec_output_file_c::~srec_output_file_c()
 }
 
 
+static const char *
+memrchr(const char *data, char c, size_t len)
+{
+    if (!data)
+        return 0;
+    const char *result = 0;
+    while (len > 0)
+    {
+        const char *p = (const char *)memchr(data, c, len);
+        if (!p)
+            break;
+        result = p;
+        size_t chunk = p - data + 1;
+        data += chunk;
+        len -= chunk;
+    }
+    return result;
+}
+
+
+static string
+build_include_file_name(const string &filename)
+{
+    const char *fn = filename.c_str();
+    // Watch out for out base class adding a line number.
+    const char *colon = strstr(fn, ": ");
+    if (!colon)
+        colon = fn + strlen(fn);
+    const char *slash = memrchr(fn, '/', colon - fn);
+    if (!slash)
+        slash = memrchr(fn, '\\', colon - fn);
+    if (slash)
+        slash++;
+    else
+        slash = fn;
+    const char *ep = memrchr(slash, '.', colon - slash);
+    if (!ep)
+        ep = colon;
+    return (string(fn, ep - fn) + ".h");
+}
+
+
+srec_output_file_c::srec_output_file_c(const string &a_file_name) :
+    srec_output_file(a_file_name),
+    prefix("eprom"),
+    taddr(0),
+    header_done(false),
+    column(0),
+    current_address(0),
+    line_length(75),
+    address_length(4),
+    constant(true),
+    include(false),
+    include_file_name(build_include_file_name(a_file_name)),
+    output_word(false),
+    hex_style(true),
+    section_style(false)
+{
+}
+
+
+srec_output::pointer
+srec_output_file_c::create(const std::string &a_file_name)
+{
+    return pointer(new srec_output_file_c(a_file_name));
+}
+
+
+void
+srec_output_file_c::command_line(srec_arglex *cmdln)
+{
+    if (cmdln->token_cur() == arglex::token_string)
+    {
+        prefix = cmdln->value_string();
+        cmdln->token_next();
+    }
+    for (;;)
+    {
+        switch (cmdln->token_cur())
+        {
+        case srec_arglex::token_constant:
+            cmdln->token_next();
+            constant = true;
+            break;
+
+        case srec_arglex::token_constant_not:
+            cmdln->token_next();
+            constant = false;
+            break;
+
+        case srec_arglex::token_include:
+            cmdln->token_next();
+            include = true;
+            break;
+
+        case srec_arglex::token_include_not:
+            cmdln->token_next();
+            include = false;
+            break;
+
+        case srec_arglex::token_c_compressed:
+            cmdln->token_next();
+            hex_style = true;
+            section_style = true;
+            break;
+
+        case srec_arglex::token_output_word:
+            cmdln->token_next();
+            output_word = true;
+            break;
+
+        case srec_arglex::token_style_hexadecimal:
+            cmdln->token_next();
+            hex_style = true;
+            break;
+
+        case srec_arglex::token_style_hexadecimal_not:
+            cmdln->token_next();
+            hex_style = false;
+            break;
+
+        case srec_arglex::token_style_section:
+        case srec_arglex::token_a430:
+        case srec_arglex::token_cl430:
+            cmdln->token_next();
+            section_style = true;
+            break;
+
+        default:
+            return;
+        }
+    }
+}
+
+
+void
+srec_output_file_c::emit_header()
+{
+    if (header_done)
+        return;
+    if (constant)
+        put_stringf("const ");
+    if (output_word)
+        put_string("unsigned short");
+    else
+        put_string("unsigned char");
+    put_char(' ');
+    put_string(prefix.c_str());
+    put_string("[] =\n{\n");
+    header_done = true;
+    column = 0;
+}
+
+
+void
+srec_output_file_c::emit_byte(int n)
+{
+    char buffer[30];
+    if (hex_style)
+        snprintf(buffer, sizeof(buffer), "0x%2.2X", (unsigned char)n);
+    else
+        snprintf(buffer, sizeof(buffer), "%u", (unsigned char)n);
+    int len = strlen(buffer);
+
+    if (column && column + 2 + len > line_length)
+    {
+        put_char('\n');
+        column = 0;
+    }
+    if (column)
+    {
+        put_char(' ');
+        ++column;
+    }
+    put_string(buffer);
+    column += len;
+    put_char(',');
+    ++column;
+}
+
+
+void
+srec_output_file_c::emit_word(unsigned int n)
+{
+    char buffer[30];
+    if (hex_style)
+        snprintf(buffer, sizeof(buffer), "0x%4.4X", (unsigned short)n);
+    else
+        snprintf(buffer, sizeof(buffer), "%u", (unsigned short)n);
+    int len = strlen(buffer);
+
+    if (column && column + 2 + len > line_length)
+    {
+        put_char('\n');
+        column = 0;
+    }
+    if (column)
+    {
+        put_char(' ');
+        ++column;
+    }
+    put_string(buffer);
+    column += len;
+    put_char(',');
+    ++column;
+}
+
+
+string
+srec_output_file_c::format_address(unsigned long addr)
+{
+    char buffer[30];
+    if (hex_style)
+        snprintf(buffer, sizeof(buffer), "0x%0*lX", address_length * 2, addr);
+    else
+        snprintf(buffer, sizeof(buffer), "%lu", addr);
+    return buffer;
+}
+
+
 void
 srec_output_file_c::write(const srec_record &record)
 {
