@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2001, 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2001, 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -21,10 +21,9 @@
 #include <lib/srec/record.h>
 
 
-srec_output_file_emon52::srec_output_file_emon52() :
-    srec_output_file(),
-    pref_block_size(16)
+srec_output_file_emon52::~srec_output_file_emon52()
 {
+    // check for termination record
 }
 
 
@@ -36,26 +35,10 @@ srec_output_file_emon52::srec_output_file_emon52(
 }
 
 
-srec_output_file_emon52::srec_output_file_emon52(
-        const srec_output_file_emon52 &) :
-    srec_output_file(),
-    pref_block_size(16)
+srec_output::pointer
+srec_output_file_emon52::create(const std::string &a_file_name)
 {
-    fatal_error("bug (%s, %d)", __FILE__, __LINE__);
-}
-
-
-srec_output_file_emon52 &
-srec_output_file_emon52::operator=(const srec_output_file_emon52 &)
-{
-    fatal_error("bug (%s, %d)", __FILE__, __LINE__);
-    return *this;
-}
-
-
-srec_output_file_emon52::~srec_output_file_emon52()
-{
-    // check for termination record
+    return pointer(new srec_output_file_emon52(a_file_name));
 }
 
 
