@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000-2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2000-2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,14 +17,15 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
+#include <cstring>
+
 #include <lib/srec/output/file/wilson.h>
 #include <lib/srec/record.h>
 
 
-srec_output_file_wilson::srec_output_file_wilson() :
-    srec_output_file(),
-    pref_block_size(32)
+srec_output_file_wilson::~srec_output_file_wilson()
 {
+    // check for termination record
 }
 
 
@@ -36,9 +37,10 @@ srec_output_file_wilson::srec_output_file_wilson(
 }
 
 
-srec_output_file_wilson::~srec_output_file_wilson()
+srec_output::pointer
+srec_output_file_wilson::create(const std::string &a_file_name)
 {
-    // check for termination record
+    return pointer(new srec_output_file_wilson(a_file_name));
 }
 
 
